# Submission - User Guide

## Prepare your runtime environment

There are three files that help you setup your environment.
1. `requirements.txt`
2. `apt.txt`
3. [(other configuration files)](https://discourse.aicrowd.com/t/how-to-specify-runtime-environment-for-your-submission/2274)

#### `requirements.txt`
You can specify the list of python packages that need to be installed in your
`requirements.txt`.

#### `apt.txt`
If there are certain system level packages that you need, you can specify them in your
`apt.txt`. If you are familiar with ubuntu/debian, this is same as installing these
packages using `apt-get install` command.

## Initial Setup

Before you submit to AIcrowd, you need to setup SSH access to our GitLab instance.
This is a one-time requirement to setup your repository.

This process involves
1. Cloning the repository
2. Replace git origin to point to your personal repository
3. Setup SSH key

Clone the repository using:
```bash
git clone https://github.com/zew/data-purchasing-challenge-2022-starter-kit.git
cd data-purchasing-challenge-2022-starter-kit
```

Now, you need to point the repository to your personal repository on AIcrowd GitLab.

```bash
git remote add aicrowd git@gitlab.aicrowd.com:<your-aicrowd-username>/data-purchasing-challenge-2022-starter-kit.git
```

To be able to push your code to GitLab, you should setup SSH keys first. Please
follow the instructions [here](https://discourse.aicrowd.com/t/how-to-add-ssh-key-to-gitlab/2603).

## Submit to AIcrowd

Add the changes as git commit.

```bash
git add --all
git commit -m "<brief summary of changes>"
```

Create and push a new tag

```bash
# Tags with prefix `submission-` are considered as submitting the codebase for submissions.
git tag submission-initial-version
git push origin master
git push origin submission-initial-version
```

## Monitor progress and score

After you have done the submission, the progress and live scores will be visible on your GitLab repository -> Issues.

Example scores report (click the image to zoom in):

<a href="https://i.imgur.com/Z8eZ2kK.png"><img src="https://i.imgur.com/Z8eZ2kK.png" width="400"></a>

<br><br>

# 🛠 Troubleshooting

### Q. My submission failed. How do I know what happened?

You can check the logs for troubleshooting the errors, the link for the same are present at the end of above report. In case you are unable to debug and need additional help please checkout the Discourse forum or Discord chat.

### Q. My docker builds fail. Can I reproduce this locally?

You can build the images locally by running the following

```bash
pip install -U aicrowd-repo2docker
aicrowd-repo2docker .
```

### Q. What is the code entrypoint?

The evaluator will use `ZEWDPCBaseRun` class present in `run.py` for all the evaluation phases.

### Q. Where should I write my code?

You need to write your code inside `ZEWDPCBaseRun` class present in `run.py`.

### Q. More questions?

In case you have any doubts or need help, you can reach out to us via [Challenge Discussions](https://www.aicrowd.com/challenges/data-purchasing-challenge-2022/discussion) or [Discord](https://discord.gg/ZHBDGEZabY).

